#ifndef RUBYSPEC_CAPI_RUBINIUS_H
#define RUBYSPEC_CAPI_RUBINIUS_H

/* #undef any HAVE_ defines that Rubinius does not have. */
#undef HAVE_RB_DEFINE_HOOKED_VARIABLE
#undef HAVE_RB_DEFINE_VARIABLE

#endif
